@@ -93,7 +93,10 @@ sub get_shared_lib_file_dist {
 sub build_shared_lib_dist {
   my ($self, $package_name, $category) = @_;
   
-  $self->compile_spvm($package_name, '(build_shared_lib_dist)', 0);
+  my $compile_success = $self->compile_spvm($package_name, '(build_shared_lib_dist)', 0);
+  unless ($compile_success) {
+    exit(255);
+  }
 
   my $cc_native = SPVM::Builder::CC->new(
     build_dir => $self->{build_dir},
