@@ -14,15 +14,15 @@ enum {
   SPVM_DESCRIPTOR_C_ID_RW,
   SPVM_DESCRIPTOR_C_ID_RO,
   SPVM_DESCRIPTOR_C_ID_WO,
+  SPVM_DESCRIPTOR_C_ID_NORW,
 };
 
-extern const char* const SPVM_DESCRIPTOR_C_ID_NAMES[];
-
 // Field information
 struct spvm_descriptor {
   int32_t id;
 };
 
 SPVM_DESCRIPTOR* SPVM_DESCRIPTOR_new(SPVM_COMPILER* compiler);
+const char* const* SPVM_DESCRIPTOR_C_ID_NAMES(void);
 
 #endif
