@@ -161,7 +161,7 @@ enum {
   SPVM_OP_C_ID_PRECOMPILE,
   SPVM_OP_C_ID_SCALAR,
   SPVM_OP_C_ID_ARRAY_FIELD_ACCESS,
-  SPVM_OP_C_ID_REF,
+  SPVM_OP_C_ID_CREATE_REF,
   SPVM_OP_C_ID_DEREF,
   SPVM_OP_C_ID_DOT3,
   SPVM_OP_C_ID_STRING_LENGTH,
@@ -178,6 +178,7 @@ enum {
   SPVM_OP_C_ID_BREAK,
   SPVM_OP_C_ID_WARN,
   SPVM_OP_C_ID_PRINT,
+  SPVM_OP_C_ID_REFOP,
 };
 
 const char* const* SPVM_OP_C_ID_NAMES(void);
@@ -279,6 +280,8 @@ SPVM_OP* SPVM_OP_new_op_assign_bool(SPVM_COMPILER* compiler, SPVM_OP* op_operand
 
 SPVM_OP* SPVM_OP_build_refcnt(SPVM_COMPILER* compiler, SPVM_OP* op_refcnt, SPVM_OP* op_term);
 
+SPVM_OP* SPVM_OP_build_refop(SPVM_COMPILER* compiler, SPVM_OP* op_refop, SPVM_OP* op_term);
+
 SPVM_OP* SPVM_OP_build_expression_statement(SPVM_COMPILER* compiler, SPVM_OP* op_expression);
 
 SPVM_OP* SPVM_OP_build_if_require_statement(SPVM_COMPILER* compiler, SPVM_OP* op_if_require, SPVM_OP* op_use, SPVM_OP* op_block_true, SPVM_OP* op_block_false);
