@@ -1,13 +1,13 @@
 #ifndef SPVM_PACKAGE_VAR_H
 #define SPVM_PACKAGE_VAR_H
 
-#include "spvm_base.h"
+#include "spvm_typedecl.h"
 
 enum {
   SPVM_PACKAGE_VAR_C_FLAG_PUBLIC = 1,
 };
 
-struct SPVM_package_var {
+struct spvm_package_var {
   const char* name;
   const char* signature;
   SPVM_TYPE* type;
